@@ -5,14 +5,14 @@ from ._quillmark import (
     CompilationError,
     Diagnostic,
     Location,
-    OutputFormat,
+    OutputFormat,  # No underscore prefix!
     ParseError,
     ParsedDocument,
     Quill,
     Quillmark,
     QuillmarkError,
     RenderResult,
-    Severity,
+    Severity,  # No underscore prefix!
     TemplateError,
     Workflow,
 )
@@ -34,4 +34,4 @@ __all__ = [
     "Workflow",
 ]
 
-__version__ = "0.1.0"
+__version__ = "0.1.0"
\ No newline at end of file
